export { default as pluralize } from "./pluralize";
export { default as singularize } from "./singularize";
export { default as camelize } from "./camelize";
export { default as underscore } from "./underscore";
export { default as humanize } from "./humanize";
export { default as titleize } from "./titleize";
export { default as tableize } from "./tableize";
export { default as classify } from "./classify";
export { default as dasherize } from "./dasherize";
export { default as foreignKey } from "./foreignKey";
export { default as ordinal } from "./ordinal";
export { default as ordinalize } from "./ordinalize";
export { default as transliterate } from "./transliterate";
export { default as parameterize } from "./parameterize";
export { default as capitalize } from "./capitalize";
export { default as inflections } from "./inflections";
export { default as transliterations } from "./transliterations";
export { default as constantify } from "./constantify";
